mysql.exceptions.server.Failed_Routine_Break_Binlog

Package mysql :: Package exceptions :: Module server :: Class Failed_Routine_Break_Binlog |
[hide private]
[frames] | no frames]

# Class Failed_Routine_Break_Binlog

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Failed_Routine_Break_Binlog

A routine failed and has neither NO SQL nor READS SQL DATA in its declaration and binary logging is enabled; if non-transactional tables were updated, the binary log will miss their changes

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`